@@ -4,11 +4,9 @@ import os, sys, pygame, math, random, ConfigParser
 from pygame.locals import *
 import gst
 
-startlevel=0
-#startlevel=15
 bpp=16
 showfps=False
-#showfps=True
+startlevel=0
 fullscreenrefresh=False
 
 pos_close =(720,10)
@@ -35,25 +33,47 @@ yellowcolor=[255,255,0]
 orangecolor=[255,127,0]
 
 config = ConfigParser.RawConfigParser()
+
+def getdefint(sct,key,val):
+    try: 
+        return config.getint(sct, key)
+    except:
+        return val
+
+def saveconfig():
+    configfile = open(settingsdir +'/issettings.cfg', "w")
+    print "writting settings"
+    config.write(configfile)
+
 try:
     configfile = open(settingsdir +'/issettings.cfg', "r")
     config.readfp(configfile)
-    hiscore = config.getint('achievements', 'highscore')
-    playsounds=config.getint('settings', 'sound')==1
-    showfps=config.getint('settings', 'showfps')==1
+    hiscore = getdefint('achievements', 'highscore',2000)
+    playsounds=getdefint('settings', 'sound',1)==1
+    showfps=getdefint('settings', 'showfps',0)==1
+    startlevel=getdefint('settings', 'startlevel',0)
+    fullscreenrefresh=getdefint('settings', 'fullscreenrefresh',0)==1
 except:
+    print configfilename + " - read failure, picking defaults"
     hiscore = 2000
     playsounds=True
     showfps=False
     
-configfile = open(settingsdir +'/issettings.cfg', "w")
+#configfile = open(settingsdir +'/issettings.cfg', "w")
 try:
     config.add_section('achievements')
 except ConfigParser.DuplicateSectionError:
     pass
 
+try:
+    config.add_section('settings')
+except ConfigParser.DuplicateSectionError:
+    pass
+
 config.set('achievements','highscore', str(hiscore))
-config.write(configfile)
+saveconfig()
+#configfile.seek(0)
+#config.write(configfile)
 
 numcirclecolors=5
 
@@ -288,14 +308,19 @@ def handlebuttonpress(event,screen,background):
         return True
     elif (event.pos[0]>720) and (event.pos[1])>soundIconTop and (event.pos[1])<soundIconTop+64:
         playsounds= not playsounds
+
         if playsounds:
             soundonsnd=pygame.mixer.Sound(appdir + "/sounds/soundon.wav")
             soundplay(soundonsnd)
             config.set('settings','sound', '1')
-            config.write(configfile)
+            saveconfig()
+#            configfile.seek(0)
+#            config.write(configfile)
         else:
             config.set('settings','sound', '0')
-            config.write(configfile)
+            saveconfig()
+#            configfile.seek(0)
+#            config.write(configfile)
 
         if playsounds:
             oggplayer.set_state(gst.STATE_PLAYING)
@@ -406,11 +431,23 @@ def Betweengames(score, screen):
 
     if score == hiscore:
         config.set('achievements','highscore', str(score))
-        config.write(configfile)
+        saveconfig()
+#        configfile.seek(0)
+#        config.write(configfile)
 
     mdown=False
     while 1:
+        message = bus.poll(gst.MESSAGE_EOS,0)
+        if message != None:
+            return True
+
         clock.tick(10)
+#       pretty hideous way of detcting song end... but seems to work
+        message = bus.poll(gst.MESSAGE_EOS,0)
+        if message != None:
+            return True
+
+
         for event in pygame.event.get():
             if event.type == QUIT:
                 return False
@@ -945,4 +982,4 @@ def PlayGame(screen):
 #import cProfile as profile
 if __name__ == "__main__":
 #    profile.run(main())
-    main()
\ No newline at end of file
+    main()
